# Collection

::: djtools.collection
::: djtools.collection.config
::: djtools.collection.playlist_builder
::: djtools.collection.playlist_filters
::: djtools.collection.shuffle_playlists
::: djtools.collection.copy_playlists
::: djtools.collection.helpers
